
# Source needed utility functions.
source(here::here("code", "seurat-utils.R"))

#' Find marker genes using Seurat
#'
#' This wraps the `Seurat::FindAllMarkers` functions.
#'
#' @param sce A SingleCellExperiment object,
#' @param pars A list of parameters passed to the function. For Seurat this has
#'   the following components:
#'   * `test.use`: The test to use.
#'
#' @details The `FindAllMarkers` function compares a specified cluster to *all*
#'   other clusters in the data.
#'
#' @return A list containing the time of the computation and results of the
#'  method.
#'
run_seurat <- function(sce, pars) {

  seurat_data <- as_seurat_data(sce)

  times <- system.time(
    result <- Seurat::FindAllMarkers(
      seurat_data,
      test.use = pars$test.use
    )
  )

  # Get the elapsed time.
  time <- times[[3]]

  list(time = time, result = result, pars = pars)
}
